# Django Logic Celery
[![Build Status](https://travis-ci.org/Borderless360/django-logic-celery.svg?branch=master)](https://travis-ci.org/Borderless360/django-logic-celery)[![Coverage Status](https://coveralls.io/repos/github/Borderless360/django-logic-celery/badge.svg?branch=master)](https://coveralls.io/github/Borderless360/django-logic-celery?branch=master)

Background transitions support for [Django Logic](https://github.com/Borderless360/django-logic)

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install Django-Logic-Celery.

```bash
pip install django-logic-celery
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)

## Project status
Under development